scanner

package
v0.0.53 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 16, 2022 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Scanner

type Scanner struct {
	Input  parse.Input
	Parser parse.Function
}

Scanner can take an input stream and execute parse results.

func New

func New(stream parse.Input, p parse.Function) *Scanner

New creates a new Scanner.

func (*Scanner) Next

func (s *Scanner) Next() (item interface{}, err error)

Next should be called repeatedly to request the next token from the stream. If

Jump to